
# Type: identifier type


A string that is intended to uniquely identify a thing May be URI in full or compact (CURIE) form

URI: [biolink:IdentifierType](https://w3id.org/biolink/vocab/IdentifierType)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **ElementIdentifier** |
